@@ -3,14 +3,13 @@
 """
 from __future__ import annotations
 
-import json
-
-from velbusaio.command_registry import register_command
+from velbusaio.command_registry import register
 from velbusaio.message import Message
 
 COMMAND_CODE = 0xF0
 
 
+@register(COMMAND_CODE)
 class ChannelNamePart1Message(Message):
     """
     send by: VMB6IN, VMB4RYLD
@@ -45,6 +44,32 @@ class ChannelNamePart1Message(Message):
         )
 
 
+@register(
+    COMMAND_CODE,
+    [
+        "VMBGP1",
+        "VMBEL1",
+        "VMBGP1-2",
+        "VMBGP2",
+        "VMBEL2",
+        "VMBGP2-2",
+        "VMBGP4",
+        "VMBEL4",
+        "VMBGP4-2",
+        "VMBGPO",
+        "VMBGPOD",
+        "VMBGPOD-2",
+        "VMBELO",
+        "VMBGP4PIR",
+        "VMBGP4PIR-2",
+        "VMBDMI",
+        "VMBDMI-R",
+        "VMBIN",
+        "VMBKP",
+        "VMBELPIR",
+        "VMBDALI",
+    ],
+)
 class ChannelNamePart1Message2(ChannelNamePart1Message):
     """
     send by: VMBGP*, VMBDALI
@@ -63,6 +88,7 @@ class ChannelNamePart1Message2(ChannelNamePart1Message):
         self.name = "".join([chr(x) for x in data[1:]])
 
 
+@register(COMMAND_CODE, ["VMB1BL", "VMB2BL"])
 class ChannelNamePart1Message3(ChannelNamePart1Message):
     """
     send by: VMBGP*
@@ -79,29 +105,3 @@ class ChannelNamePart1Message3(ChannelNamePart1Message):
         self.set_attributes(priority, address, rtr)
         self.channel = (data[0] >> 1) & 0x03
         self.name = "".join([chr(x) for x in data[1:]])
-
-
-register_command(COMMAND_CODE, ChannelNamePart1Message)
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBGP1")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBEL1")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBGP1-2")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBGP2")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBEL2")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBGP2-2")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBGP4")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBEL4")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBGP4-2")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBGPO")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBGPOD")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBGPOD-2")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBELO")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBGP4PIR")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBGP4PIR-2")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBDMI")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBDMI-R")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBIN")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBKP")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBELPIR")
-register_command(COMMAND_CODE, ChannelNamePart1Message3, "VMB1BL")
-register_command(COMMAND_CODE, ChannelNamePart1Message3, "VMB2BL")
-register_command(COMMAND_CODE, ChannelNamePart1Message2, "VMBDALI")
