@@ -3,14 +3,13 @@
 """
 from __future__ import annotations
 
-import json
-
-from velbusaio.command_registry import register_command
+from velbusaio.command_registry import register
 from velbusaio.message import Message
 
 COMMAND_CODE = 0xBE
 
 
+@register(COMMAND_CODE, ["VMB7IN"])
 class CounterStatusMessage(Message):
     """
     send by: VMB7IN
@@ -42,22 +41,8 @@ class CounterStatusMessage(Message):
         self.counter = (data[1] << 24) + (data[2] << 16) + (data[3] << 8) + data[4]
         self.delay = (data[5] << 8) + data[6]
 
-    def to_json(self):
-        """
-        :return: str
-        """
-        json_dict = self.to_json_basic()
-        json_dict["pulses"] = self.pulses
-        json_dict["counter"] = self.counter
-        json_dict["delay"] = self.delay
-        json_dict["channel"] = self.channel
-        return json.dumps(json_dict)
-
     def get_channels(self):
         """
         :return: list
         """
         return self.channel
-
-
-register_command(COMMAND_CODE, CounterStatusMessage, "VMB7IN")
