@@ -3,10 +3,9 @@
 """
 from __future__ import annotations
 
-import json
 import struct
 
-from velbusaio.command_registry import register_command
+from velbusaio.command_registry import register
 from velbusaio.message import Message
 
 COMMAND_CODE = 0xB8
@@ -22,6 +21,7 @@ LED_FAST_BLINKING = 1 << 5
 LED_VERY_FAST_BLINKING = 1 << 4
 
 
+@register(COMMAND_CODE, ["VMB4DC", "VMBDMI", "VMBDMI-R"])
 class DimmerChannelStatusMessage(Message):
     """
     sent by: VMB4DC
@@ -97,8 +97,3 @@ class DimmerChannelStatusMessage(Message):
             )
             + struct.pack(">L", self.delay_time)[-3:]
         )
-
-
-register_command(COMMAND_CODE, DimmerChannelStatusMessage, "VMB4DC")
-register_command(COMMAND_CODE, DimmerChannelStatusMessage, "VMBDMI")
-register_command(COMMAND_CODE, DimmerChannelStatusMessage, "VMBDMI-R")
