@@ -3,14 +3,13 @@
 """
 from __future__ import annotations
 
-import json
-
-from velbusaio.command_registry import register_command
+from velbusaio.command_registry import register
 from velbusaio.message import Message
 
 COMMAND_CODE = 0xD4
 
 
+@register(COMMAND_CODE)
 class EdgeSetCustomColor(Message):
     """
     send by:
@@ -54,6 +53,3 @@ class EdgeSetCustomColor(Message):
                 self.blue,
             ]
         )
-
-
-register_command(COMMAND_CODE, EdgeSetCustomColor)
