@@ -3,12 +3,13 @@
 """
 from __future__ import annotations
 
-from velbusaio.command_registry import register_command
+from velbusaio.command_registry import register
 from velbusaio.message import Message
 
 COMMAND_CODE = 0xF8
 
 
+@register(COMMAND_CODE)
 class FastBlinkingLedMessage(Message):
     """
     send by: VMB4RYLD
@@ -35,6 +36,3 @@ class FastBlinkingLedMessage(Message):
         :return: bytes
         """
         return bytes([COMMAND_CODE, self.channels_to_byte(self.leds)])
-
-
-register_command(COMMAND_CODE, FastBlinkingLedMessage)
