@@ -3,12 +3,13 @@
 """
 from __future__ import annotations
 
-from velbusaio.command_registry import register_command
+from velbusaio.command_registry import register
 from velbusaio.message import Message
 
 COMMAND_CODE = 0xAC
 
 
+@register(COMMAND_CODE)
 class MemoTextMessage(Message):
     """
     send by:
@@ -38,6 +39,3 @@ class MemoTextMessage(Message):
         while len(self.memo_text) < 5:
             self.memo_text += chr(0)
         return bytes([COMMAND_CODE, 0x00, self.start]) + bytes(self.memo_text, "utf-8")
-
-
-register_command(COMMAND_CODE, MemoTextMessage)
