@@ -3,14 +3,13 @@
 """
 from __future__ import annotations
 
-import json
-
-from velbusaio.command_registry import register_command
+from velbusaio.command_registry import register
 from velbusaio.message import Message
 
 COMMAND_CODE = 0xFE
 
 
+@register(COMMAND_CODE)
 class MemoryDataMessage(Message):
     """
     send by: VMB6IN, VMB4RYLD
@@ -41,6 +40,3 @@ class MemoryDataMessage(Message):
         :return: bytes
         """
         return bytes([COMMAND_CODE, self.high_address, self.low_address, self.data])
-
-
-register_command(COMMAND_CODE, MemoryDataMessage)
