@@ -1,12 +1,15 @@
 """
 :author: Thomas Delaet <thomas@delaet.org>
 """
-from velbusaio.command_registry import register_command
+from __future__ import annotations
+
+from velbusaio.command_registry import register
 from velbusaio.message import Message
 
 COMMAND_CODE = 0x0B
 
 
+@register(COMMAND_CODE)
 class ReceiveBufferFullMessage(Message):
     """
     send by:
@@ -33,6 +36,3 @@ class ReceiveBufferFullMessage(Message):
         :return: bytes
         """
         return bytes([COMMAND_CODE])
-
-
-register_command(COMMAND_CODE, ReceiveBufferFullMessage)
