@@ -3,15 +3,15 @@
 """
 from __future__ import annotations
 
-import json
 import time
 
-from velbusaio.command_registry import register_command
+from velbusaio.command_registry import register
 from velbusaio.message import Message
 
 COMMAND_CODE = 0xAF
 
 
+@register(COMMAND_CODE)
 class SetDaylightSaving(Message):
     """
     received by all modules
@@ -45,6 +45,3 @@ class SetDaylightSaving(Message):
         :return: bytes
         """
         return bytes([COMMAND_CODE, self._ds])
-
-
-register_command(COMMAND_CODE, SetDaylightSaving)
