@@ -3,14 +3,13 @@
 """
 from __future__ import annotations
 
-import json
-
-from velbusaio.command_registry import register_command
+from velbusaio.command_registry import register
 from velbusaio.message import Message
 
 COMMAND_CODE = 0x01
 
 
+@register(COMMAND_CODE)
 class SwitchRelayOffMessage(Message):
     """
     send by:
@@ -43,6 +42,3 @@ class SwitchRelayOffMessage(Message):
         :return: bytes
         """
         return bytes([COMMAND_CODE, self.channels_to_byte(self.relay_channels)])
-
-
-register_command(COMMAND_CODE, SwitchRelayOffMessage)
