@@ -3,14 +3,13 @@
 """
 from __future__ import annotations
 
-import json
-
-from velbusaio.command_registry import register_command
+from velbusaio.command_registry import register
 from velbusaio.message import Message
 
 COMMAND_CODE = 0xDC
 
 
+@register(COMMAND_CODE)
 class SwitchToDayMessage(Message):
     """
     send by:
@@ -29,19 +28,8 @@ class SwitchToDayMessage(Message):
         self.needs_no_rtr(rtr)
         self.set_attributes(priority, address, rtr)
 
-    def to_json(self):
-        """
-        :return: str
-        """
-        json_dict = self.to_json_basic()
-        json_dict["sleep_time"] = self.sleep
-        return json.dumps(json_dict)
-
     def data_to_binary(self):
         """
         :return: bytes
         """
-        return bytes([COMMAND_CODE, 0x00, 0x00])
-
-
-register_command(COMMAND_CODE, SwitchToDayMessage)
+        return bytes([COMMAND_CODE, self.sleep >> 8, self.sleep & 0xFF])
