@@ -1,12 +1,15 @@
 """
 :author: Thomas Delaet <thomas@delaet.org>
 """
-from velbusaio.command_registry import register_command
+from __future__ import annotations
+
+from velbusaio.command_registry import register
 from velbusaio.message import Message
 
 COMMAND_CODE = 0xF9
 
 
+@register(COMMAND_CODE)
 class VeryFastBlinkingLedMessage(Message):
     """
     send by: VMB4RYLD
@@ -33,6 +36,3 @@ class VeryFastBlinkingLedMessage(Message):
         :return: bytes
         """
         return bytes([COMMAND_CODE, self.channels_to_byte(self.leds)])
-
-
-register_command(COMMAND_CODE, VeryFastBlinkingLedMessage)
